import { QueryList, TemplateRef, AfterContentChecked, EventEmitter } from '@angular/core';
/**
 * A directive to wrap tab titles that need to contain HTML markup or other directives.
 *
 * Alternatively you could use the `NgbTab.title` input for string titles.
 */
import * as ɵngcc0 from '@angular/core';
export declare class CloSecondaryNavigationTabTitle {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: ɵngcc0.ɵɵFactoryDeclaration<CloSecondaryNavigationTabTitle, never>;
    static ɵdir: ɵngcc0.ɵɵDirectiveDeclaration<CloSecondaryNavigationTabTitle, "ng-template[cloNavigationTabTitle]", never, {}, {}, never>;
}
/**
 * A directive to wrap content to be displayed in a tab.
 */
export declare class CloSecondaryNavigationTabContent {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: ɵngcc0.ɵɵFactoryDeclaration<CloSecondaryNavigationTabContent, never>;
    static ɵdir: ɵngcc0.ɵɵDirectiveDeclaration<CloSecondaryNavigationTabContent, "ng-template[cloNavigationTabContent]", never, {}, {}, never>;
}
/**
 * A directive representing an individual tab.
 */
export declare class CloSecondaryNavigationTab implements AfterContentChecked {
    /**
     * The tab identifier.
     *
     * Must be unique for the entire document for proper accessibility support.
     */
    id: string;
    /**
     * The tab title.
     *
     * Use the [`cloSecondaryNavigationTabTitle`](#/components/tabset/api#NgbTabTitle) directive for non-string titles.
     */
    title: string;
    /**
     * If `true`, the current tab is disabled and can't be toggled.
     */
    disabled: boolean;
    titleTpl: CloSecondaryNavigationTabTitle | null;
    contentTpl: CloSecondaryNavigationTabContent | null;
    titleTpls: QueryList<CloSecondaryNavigationTabTitle>;
    contentTpls: QueryList<CloSecondaryNavigationTabContent>;
    ngAfterContentChecked(): void;
    static ɵfac: ɵngcc0.ɵɵFactoryDeclaration<CloSecondaryNavigationTab, never>;
    static ɵdir: ɵngcc0.ɵɵDirectiveDeclaration<CloSecondaryNavigationTab, "clo-navigation-tab", never, { "id": "id"; "disabled": "disabled"; "title": "title"; }, {}, ["titleTpls", "contentTpls"]>;
}
/**
 * The payload of the change event fired right before the tab change.
 */
export interface CloSecondaryNavigationTabChangeEvent {
    /**
     * The id of the currently active tab.
     */
    activeId: string;
    /**
     * The id of the newly selected tab.
     */
    nextId: string;
    /**
     * Calling this function will prevent tab switching.
     */
    preventDefault: () => void;
}
/**
 * A component that makes it easy to create tabbed interface.
 */
export declare class CloSecondaryNavigation implements AfterContentChecked {
    justifyClass: string;
    tabs: QueryList<CloSecondaryNavigationTab>;
    /**
     * The identifier of the tab that should be opened **initially**.
     *
     * For subsequent tab switches use the `.select()` method and the `(tabChange)` event.
     */
    activeId: string;
    /**
     * If `true`, non-visible tabs content will be removed from DOM. Otherwise it will just be hidden.
     */
    destroyOnHide: boolean;
    /**
     * The horizontal alignment of the tabs with flexbox utilities.
     */
    set justify(className: 'start' | 'center' | 'end' | 'fill' | 'justified');
    /**
     * The orientation of the tabset.
     */
    orientation: 'horizontal' | 'vertical';
    /**
     * Type of navigation to be used for tabs.
     *
     * Currently Bootstrap supports only `"tabs"` and `"pills"`.
     *
     * Since `3.0.0` can also be an arbitrary string (ex. for custom themes).
     */
    type: 'tabs' | 'pills' | string;
    /**
     * Options are secondary and tertiary, defaults to secondary
     */
    tabType: 'secondary' | 'tertiary';
    /**
     * A tab change event emitted right before the tab change happens.
     *
     * See [`NgbTabChangeEvent`](#/components/tabset/api#NgbTabChangeEvent) for payload details.
     */
    tabChange: EventEmitter<CloSecondaryNavigationTabChangeEvent>;
    /**
     * Selects the tab with the given id and shows its associated content panel.
     *
     * Any other tab that was previously selected becomes unselected and its associated pane is removed from DOM or
     * hidden depending on the `destroyOnHide` value.
     */
    select(tabId: string): void;
    ngAfterContentChecked(): void;
    private _getTabById;
    static ɵfac: ɵngcc0.ɵɵFactoryDeclaration<CloSecondaryNavigation, never>;
    static ɵcmp: ɵngcc0.ɵɵComponentDeclaration<CloSecondaryNavigation, "clo-tab-navigation", ["cloSecondaryNavigation"], { "destroyOnHide": "destroyOnHide"; "tabType": "tabType"; "justify": "justify"; "activeId": "activeId"; "orientation": "orientation"; "type": "type"; }, { "tabChange": "tabChange"; }, ["tabs"], never>;
}

//# sourceMappingURL=secondary-navigation.d.ts.map