import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy, OnInit, QueryList } from '@angular/core';
import { CloFilterTableService } from './clo-filter-table.service';
import { NgbModal } from '../modal/modal.module';
import { Observable } from 'rxjs';
import { FormControl } from '@angular/forms';
import { CloMobileCard } from './table';
/**
 *  Filter Options
 */
export declare class CloFilterOption implements OnInit {
    /**
     *  If not specified will default to value
     */
    title: string;
    value: string | number;
    applied: boolean;
    constructor();
    ngOnInit(): void;
}
/**
 *  Filter Groups to organize filters
 */
export declare class CloFilterGroup {
    title: string;
    applyAttribute: string;
    options: QueryList<CloFilterOption>;
    constructor();
}
/**
 *  Filter Block
 */
export declare class CloFilters {
    filterGroups: QueryList<CloFilterGroup>;
}
/**
 *  Export Option
 */
export declare class CloExportOption {
    /**
     * Emits when option is selected
     */
    selected: EventEmitter<any>;
    /**
     * The title to be displayed in the dropdown
     */
    title: string;
    constructor();
}
/**
 * The component where search, filters and export options live.  It can be placed anywhere on the view to interact with the table.
 */
export declare class CloTableBlock implements OnInit, AfterViewInit, OnDestroy {
    private elementRef;
    private filterTableService;
    private ref;
    private modalService;
    searchFilter: string;
    /**
     * This is required to work.  You must have the table id in this format
     * '#TableId'
     */
    tableId: string;
    tableTitle: any;
    tableDataCount: number;
    isSearchFilterRequired: boolean;
    /**
     * Allows the search function
     */
    searchable: boolean;
    filterApplied: EventEmitter<any>;
    /**
     * This returns an object indicating which modal was toggled
     *    object{
     *      modalName: string
     *      toggleStatus: string = opened/closed
     *    }
     */
    modalToggled: EventEmitter<any>;
    private appliedFilters;
    private searchableData;
    filters: CloFilters;
    exportOptions: QueryList<CloExportOption>;
    modalSearchInput: ElementRef;
    searchInput: ElementRef;
    private readonly filterSubscription;
    searchField: FormControl;
    mobileCards: QueryList<CloMobileCard>;
    tableTypeName: string;
    visibleCards: number;
    private modal;
    open(content: any): void;
    private emitModalToggled;
    search: (text$: Observable<string>) => Observable<any[]>;
    ngOnDestroy(): void;
    constructor(elementRef: ElementRef, filterTableService: CloFilterTableService, ref: ChangeDetectorRef, modalService: NgbModal);
    ngAfterViewInit(): void;
    ngOnInit(): void;
    unselectInputInIos(event: any): void;
    isiOS(): RegExpMatchArray;
    changeSearchFilter(e: any): void;
    applySearchFilter(value: any): void;
    applyFilter(event: any, value: any, attribute: any, title?: any): void;
    clearInput(e: any): void;
    onResize(event: any): void;
}
